TableRow

Trait TableRow 

pub trait TableRow {
    // Required methods
    fn get_fields() -> Vec<&'static str>;
    fn get_field_types() -> Vec<&'static str>;

    // Provided method
    fn field_count() -> usize { ... }
}

Required Methods

fn get_fields() -> Vec<&'static str>

Returns a vector containing the names of the fields

fn get_field_types() -> Vec<&'static str>

Returns a vector containing the types of the fields

Provided Methods

fn field_count() -> usize

Returns the amount of fields in this struct

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors